@@ -1,4 +1,4 @@
-# Copyright 2001-2010 by Roger Bivand
+# Copyright 2001-2013 by Roger Bivand and Elias Krainski
 #
 
 
@@ -19,24 +19,34 @@ plot.nb <- function(x, coords, col="black", points=TRUE, add=FALSE,
 	}
 	cardnb <- card(nb)
 	if (length(col) < n) col <- rep(col[1], n)
-	for (i in 1:n) {
-		if (cardnb[i] > 0) {
-        		inb <- nb[[i]]
-        		for (j in inb) {
-				if (sym) {
-					lines(c(x[i], x[j]), c(y[i], y[j]),
-						col=col[i], ...)
-				} else {
-					if (arrows) 
-						arrows(x[i], y[i], x[j], y[j], 
-						col=col[i], length=length, ...)
-					else lines(c(x[i], x[j]), c(y[i], y[j]),
-						col=col[i], ...)
-				}
+#	for (i in 1:n) {
+#		if (cardnb[i] > 0) {
+#       		inb <- nb[[i]]
+#        		for (j in inb) {
+#				if (sym) {
+#					lines(c(x[i], x[j]), c(y[i], y[j]),
+#						col=col[i], ...)
+#				} else {
+#					if (arrows) 
+#						arrows(x[i], y[i], x[j], y[j], 
+#						col=col[i], length=length, ...)
+#					else lines(c(x[i], x[j]), c(y[i], y[j]),
+#						col=col[i], ...)
+#				}
+#
+#			}
+#		}
+#	}
+
+# Elias Krainski Tue, 21 May 2013
+
+   i <- rep(1:n, cardnb)
+   j <- unlist(nb)
+   if (arrows)
+     arrows(x[i], y[i], x[j], y[j], col=col[i], length = length, ...)
+   else segments(x[i], y[i], x[j], y[j], col=col[i], ...)
+
 
-			}
-		}
-	}
 	if (points) points(x, y, ...)
 }
 
